==> imsdk-plus-7.9.5680-sources.jar: com/tencent/imsdk/manager/SDKConfig.java <==
package com.tencent.imsdk.manager;

import com.tencent.imsdk.common.SystemUtil;

public class SDKConfig {
    public long sdkAppId = 0;
    public String sdkInitPath = "";
    public long sdkInstanceType = 0;
    public boolean isTestEnvironment = false;
    public boolean enableQuic = false;
    public boolean isIPv6Prior = false;
    public String stringUIPlatform = "";
    public int numberUIPlatform = 0;
    public DeviceInfo deviceInfo = new DeviceInfo();
    public NetworkInfo networkInfo = new NetworkInfo();
    public ProxyInfo proxyInfo = new ProxyInfo();
    public DatabaseEncryptInfo databaseEncryptInfo = new DatabaseEncryptInfo();
    public PacketRetryInfo packetRetryInfo = new PacketRetryInfo();
    public LogSetting logSetting = new LogSetting();
    public String packageName = "";
    public String appName = "";
    public int applicationID = 0;

    public static class DeviceInfo {
        public String deviceId = "";
        public String deviceType = "";
        public long deviceBrand = 0;
        public String systemVersion = "";

        public static float onGetAppCpuUsage() {
            return 0.0f;
        }

        public static float onGetSysCpuUsage() {
            return 0.0f;
        }

        public static int onGetAppMemUsage() {
            return 0;
        }
    }

    public static class NetworkInfo {
        public int networkType = 0;
        public int ipType = 1;
        public String networkId = "";
        public long wifiNetworkHandle = 0;
        public long xgNetworkHandle = 0;
        public long initializeCostTime = 0;
        public boolean networkConnected = false;

        public void clean() {
            networkType = 0;
            ipType = 1;
            networkId = "";
            wifiNetworkHandle = 0;
            xgNetworkHandle = 0;
            initializeCostTime = 0;
            networkConnected = false;
        }
    }

    public static class ProxyInfo {
        public int proxyType = 0;
        public String proxyHost = "";
        public int proxyPort = 0;
        public String proxyUsername = "";
        public String proxyPassword = "";

        public void clean() {
            proxyType = 0;
            proxyHost = "";
            proxyPort = 0;
            proxyUsername = "";
            proxyPassword = "";
        }
    }

    public static class DatabaseEncryptInfo {
        public int encryptType = 0;
        public String encryptKey = "";

        public void clean() {
            encryptType = 0;
            encryptKey = "";
        }
    }

    public static class PacketRetryInfo {
        public int maxRetryCount = 0;
        public int packetRequestTimeout = 0;

        public void clean() {
            maxRetryCount = 0;
            maxRetryCount = 0;
        }
    }

    public static class LogSetting {
        public boolean enableConsoleLog = true;
        public int logLevel = 0;
        public String logFilePath = "";
    }

    public static float getAppMemoryUsage() {
        return SystemUtil.getAppMemory();
    }

    public static float getAppCpuUsage() {
        return SystemUtil.getAppCpuUsage();
    }

    public static float getSysCpuUsage() {
        return SystemUtil.getSysCpuUsage();
    }
}

==> imsdk-plus-8.8.7359-sources.jar: com/tencent/imsdk/manager/SDKConfig.java <==
package com.tencent.imsdk.manager;

import com.tencent.imsdk.common.SystemUtil;

public class SDKConfig {
    public long sdkAppId = 0;
    public String sdkInitPath = "";
    public long sdkInstanceType = 0;
    public boolean isTestEnvironment = false;
    public boolean enableQuic = false;
    public boolean isIPv6Prior = false;
    public String stringUIPlatform = "";
    public int numberUIPlatform = 0;
    public DeviceInfo deviceInfo = new DeviceInfo();
    public NetworkInfo networkInfo = new NetworkInfo();
    public ProxyInfo proxyInfo = new ProxyInfo();
    public DatabaseEncryptInfo databaseEncryptInfo = new DatabaseEncryptInfo();
    public PacketRetryInfo packetRetryInfo = new PacketRetryInfo();
    public LogSetting logSetting = new LogSetting();
    public String packageName = "";
    public String appName = "";
    public int applicationID = 0;
    public boolean disableHttpRequest = false;

    public static class DeviceInfo {
        public String deviceType = "";
        public long deviceBrand = 0;
        public String systemVersion = "";
    }

    public static class NetworkInfo {
        public int networkType = 0;
        public int ipType = 1;
        public String networkId = "";
        public long wifiNetworkHandle = 0;
        public long xgNetworkHandle = 0;
        public long initializeCostTime = 0;
        public boolean networkConnected = false;

        public void clean() {
            networkType = 0;
            ipType = 1;
            networkId = "";
            wifiNetworkHandle = 0;
            xgNetworkHandle = 0;
            initializeCostTime = 0;
            networkConnected = false;
        }
    }

    public static class ProxyInfo {
        public int proxyType = 0;
        public String proxyHost = "";
        public int proxyPort = 0;
        public String proxyUsername = "";
        public String proxyPassword = "";

        public void clean() {
            proxyType = 0;
            proxyHost = "";
            proxyPort = 0;
            proxyUsername = "";
            proxyPassword = "";
        }
    }

    public static class DatabaseEncryptInfo {
        public int encryptType = 0;
        public String encryptKey = "";

        public void clean() {
            encryptType = 0;
            encryptKey = "";
        }
    }

    public static class PacketRetryInfo {
        public int maxRetryCount = 0;
        public int packetRequestTimeout = 0;

        public void clean() {
            maxRetryCount = 0;
            maxRetryCount = 0;
        }
    }

    public static class LogSetting {
        public boolean enableConsoleLog = true;
        public int logLevel = 0;
        public String logFilePath = "";
    }

    public static float getAppMemoryUsage() {
        return SystemUtil.getAppMemory();
    }

    public static float getAppCpuUsage() {
        return SystemUtil.getAppCpuUsage();
    }

    public static float getSysCpuUsage() {
        return SystemUtil.getSysCpuUsage();
    }

    public static String getDeviceID() {
        return SystemUtil.getDeviceID();
    }
}
